/*++
Copyright (c) 1984-2007 Sangoma Technologies

Module Name:

    public.h

Abstract:

    This module contains the common declarations shared by driver
    and user applications.

Author:

     David Rokhvarg   Sep 16, 2000
     
Environment:

    user and kernel
Notes:


Revision History:


--*/

//
// Define an Interface Guid for bus enumerator class.
// This GUID is used to register (IoRegisterDeviceInterface) 
// an instance of an interface so that enumerator application 
// can send an ioctl to the BUS DRIVER.
//

DEFINE_GUID(GUID_SANGOMA_BUS_ENUMERATOR_INTERFACE_CLASS, 
		0x21c9b975, 0x4647, 0x40f5, 0xa3, 0xdc, 0x46, 0x83, 0x15, 0x76, 0xe0, 0x4e);
// {21C9B975-4647-40f5-A3DC-46831576E04E}
  
//
// Define an Interface Guid for Sangoma device class.
// This GUID is used to register (IoRegisterDeviceInterface) 
// an instance of an interface so that user application 
// can control the SANGOMA DEVICE.
//
DEFINE_GUID(GUID_SANGOMA_DEVICE_INTERFACE_CLASS, 
0x696086f8, 0xc1b6, 0x4f4c, 0x81, 0x5f, 0xcc, 0x3e, 0xa0, 0x41, 0x4d, 0x27);
// {696086F8-C1B6-4f4c-815F-CC3EA0414D27}


//
// Define a Setup Class GUID for Sangoma Class. 
// This is same as the Sangoma CLASS guid in the INF files.
// DDK: For device setup classes, use the format GUID_DEVCLASS_xxxx
//

DEFINE_GUID(GUID_DEVCLASS_SANGOMA_ADAPTER, 
0x680d0063, 0x63ed, 0x4e66, 0xa2, 0xcc, 0x6f, 0x54, 0xcb, 0x33, 0x1c, 0xf5);

#define GUID_DEVCLASS_SANGOMA_ADAPTER_STR "{680D0063-63ED-4E66-A2CC-6F54CB331CF5}"

//Only the wanpipe.sys is the real Network driver!
//Net class
//{4d36e972-e325-11ce-bfc1-08002be10318}

DEFINE_GUID(GUID_SD_BUSENUM_PDO, 
        0x9d3039dd, 0xcca5, 0x4b4d, 0xb3, 0x3d, 0xe2, 0xdd, 0xc8, 0xa8, 0xc5, 0x2e);
// {9D3039DD-CCA5-4b4d-B33D-E2DDC8A8C52E}

//
// GUID definition are required to be outside of header inclusion pragma to avoid
// error during precompiled headers.
//

#ifndef __WANPIPE_PUBLIC_H
#define __WANPIPE_PUBLIC_H

#define SANG_BUS_REG_KEY				"SYSTEM\\CurrentControlSet\\Services\\busenum"
#define SANG_PROGRAM_FILES_DIRECTORY	"\"%ProgramFiles%\"\\Sangoma\\"
#define SANG_PROGRAM_INCLUDE_DIRECTORY	"\"%ProgramFiles%\"\\Sangoma\\include"
#define SANG_PROGRAM_LIB_DIRECTORY		"\"%ProgramFiles%\"\\Sangoma\\api\\lib"

#define SANG_WP_LOG_FILE	"wanpipelog.txt"

/////////////////////////////////////////////////////////////////////////////////////
//
//it is simpler to allocte new devices if all hardware IDs of the SAME length
//
//IDs of virtual Adapters
										//for S5141, S5142(CPU A), S5143 (FT1)
#define BUS_HARDWARE_IDS_CPU_A_S5141    L"CommsAdapter\\SangomaAdapterCPUA_S5141\0"
										//CPU B on S5142 card
#define BUS_HARDWARE_IDS_CPU_B_S5142    L"CommsAdapter\\SangomaAdapterCPUB_S5142\0"

										//for S5147 (dual TE1), CPU A
#define BUS_HARDWARE_IDS_CPU_A_S5147    L"CommsAdapter\\SangomaAdapterCPUA_S5147\0"
										//for S5147 (dual TE1), CPU B
#define BUS_HARDWARE_IDS_CPU_B_S5147    L"CommsAdapter\\SangomaAdapterCPUB_S5147\0"

										//for S5144 (single TE1)
#define BUS_HARDWARE_IDS_CPU_A_S5144    L"CommsAdapter\\SangomaAdapterCPUA_S5144\0"
										//for S5145 (56K)
#define BUS_HARDWARE_IDS_CPU_A_S5145    L"CommsAdapter\\SangomaAdapterCPUA_S5145\0"
										//for S508
#define BUS_HARDWARE_IDS__S508_S5080    L"CommsAdapter\\SangomaAdapterS508_S5080\0"


#define BUS_HARDWARE_IDS_AFT_LINE1		L"CommsAdapter\\SangomaAdapter_AFT_LINE1\0"
#define BUS_HARDWARE_IDS_AFT_LINE2		L"CommsAdapter\\SangomaAdapter_AFT_LINE2\0"
#define BUS_HARDWARE_IDS_AFT_LINE3		L"CommsAdapter\\SangomaAdapter_AFT_LINE3\0"
#define BUS_HARDWARE_IDS_AFT_LINE4		L"CommsAdapter\\SangomaAdapter_AFT_LINE4\0"
#define BUS_HARDWARE_IDS_AFT_LINE5		L"CommsAdapter\\SangomaAdapter_AFT_LINE5\0"
#define BUS_HARDWARE_IDS_AFT_LINE6		L"CommsAdapter\\SangomaAdapter_AFT_LINE6\0"
#define BUS_HARDWARE_IDS_AFT_LINE7		L"CommsAdapter\\SangomaAdapter_AFT_LINE7\0"
#define BUS_HARDWARE_IDS_AFT_LINE8		L"CommsAdapter\\SangomaAdapter_AFT_LINE8\0"

#if 0
//November 30, 2009 - different IDs make firmware unnecessary difficult
# define BUS_HARDWARE_IDS_AFT_A200		BUS_HARDWARE_IDS_AFT_LINE1
# define BUS_HARDWARE_IDS_AFT_A500		BUS_HARDWARE_IDS_AFT_LINE1
# define BUS_HARDWARE_IDS_A056_LINE1	BUS_HARDWARE_IDS_AFT_LINE1
#else
# define BUS_HARDWARE_IDS_AFT_A200		L"CommsAdapter\\SangomaAdapter_AFT__A200\0"
# define BUS_HARDWARE_IDS_AFT_A500		L"CommsAdapter\\SangomaAdapter_A500__BRI\0"
# define BUS_HARDWARE_IDS_A056_LINE1	L"CommsAdapter\\SangomaAdapter_A056__56K\0"
#endif

#define BUS_HARDWARE_IDS_ADSL			L"CommsAdapter\\SangomaAdapter_S518_ADSL\0"


//NOTE: all IDs above MUST be of the SAME length!!
#define BUS_HARDWARE_IDS_LENGTH    sizeof(BUS_HARDWARE_IDS_CPU_A_S5141)

/////////////////////////////////////////////////////////////////////////////////////

//IDs of virtual Net Interfaces
//Frame Relay
#define FRAME_REL_HARDWARE_IDS_S514     L"SangomaAdapter\\FrameRelayS514\0"
#define FRAME_REL_HARDWARE_IDS_S508     L"SangomaAdapter\\FrameRelayS508\0"
#define FRAME_REL_HARDWARE_IDS_LENGTH   sizeof(FRAME_REL_HARDWARE_IDS_S514)
//PPP
#define PPP_HARDWARE_IDS_S514           L"SangomaAdapter\\PPP_S514\0"
#define PPP_HARDWARE_IDS_S508           L"SangomaAdapter\\PPP_S508\0"
#define PPP_HARDWARE_IDS_LENGTH			sizeof(PPP_HARDWARE_IDS_S514)
//X25
#define X25_HARDWARE_IDS_S514           L"SangomaAdapter\\X25_S514\0"
#define X25_HARDWARE_IDS_S508           L"SangomaAdapter\\X25_S508\0"
#define X25_HARDWARE_IDS_LENGTH			sizeof(X25_HARDWARE_IDS_S514)
//CHDLC
#define CHDLC_HARDWARE_IDS_S514         L"SangomaAdapter\\CHDLC_S514\0"
#define CHDLC_HARDWARE_IDS_S508         L"SangomaAdapter\\CHDLC_S508\0"
#define CHDLC_HARDWARE_IDS_LENGTH		sizeof(CHDLC_HARDWARE_IDS_S514)

//
//Exposing DIFFERENT ID at each level will allow user
//simply "Search for the driver" instead of installing the
//driver manually.
//

//sdladrv.sys will expose this ID for upper drivers:
#define AFT_IF_HARDWARE_IDS			L"SangomaAdapter\\AFT_IFACE\0"
#define AFT_IF_HARDWARE_IDS_LENGTH	sizeof(AFT_IF_HARDWARE_IDS)

//sdladrv.sys:	one EXEPTION - ADSL card will expose SPROTOCOL_IF_IDS.
//				The reasons are: 1 .there is NO protocol layer (at this point)
//				for the ADSL card. 2. LQ project requires it for automatic
//				install on Embedded XP.
#define ADSL_IF_IDS					L"SangomaAdapter\\ADSL_NET__IFACE\0"
#define ADSL_IF_IDS_LENGTH			sizeof(ADSL_IF_IDS)

//sprotocol.sys will expose this ID for upper drivers:
#define SPROTOCOL_IF_IDS			L"SangomaAdapter\\SPROTOCOL_IFACE\0"
#define SPROTOCOL_IF_IDS_LENGTH		sizeof(SPROTOCOL_IF_IDS)

/////////////////////////////////////////////////////////////////////////////////////

#define FILE_DEVICE_BUSENUM         FILE_DEVICE_BUS_EXTENDER

#define BUSENUM_IOCTL(_index_) \
    CTL_CODE (FILE_DEVICE_BUSENUM, _index_, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_BUSENUM_PLUGIN_HARDWARE               BUSENUM_IOCTL (0x0)
#define IOCTL_BUSENUM_UNPLUG_HARDWARE               BUSENUM_IOCTL (0x1)
#define IOCTL_BUSENUM_EJECT_HARDWARE                BUSENUM_IOCTL (0x2)
#define IOCTL_SANGOMA_DONT_DISPLAY_IN_UI_DEVICE     BUSENUM_IOCTL (0x3)

//
//  Data structure used in PlugIn and UnPlug ioctls
//
#pragma warning( disable : 4200 )	/* zero-sized array in struct */
typedef struct _BUSENUM_PLUGIN_HARDWARE
{
    //
    // sizeof (struct _BUSENUM_HARDWARE)
    //
    IN ULONG Size;                          
    
    //
    // Unique serial number of the device to be enumerated.
    // Enumeration will be failed if another device on the 
    // bus has the same serail number.
    //

    IN ULONG SerialNo;

    
    //
    // An array of (zero terminated wide character strings). The array itself
    //  also null terminated (ie, MULTI_SZ)
    //
    IN  WCHAR   HardwareIDs[]; 
                                                                        
} BUSENUM_PLUGIN_HARDWARE, *PBUSENUM_PLUGIN_HARDWARE;
/* restore warning behavior to its default value*/
#pragma warning( default : 4200 )	/* zero-sized array in struct */

typedef struct _BUSENUM_UNPLUG_HARDWARE
{
    //
    // sizeof (struct _REMOVE_HARDWARE)
    //

    IN ULONG Size;                                    

    //
    // Serial number of the device to be plugged out    
    //

    ULONG   SerialNo;
    
    ULONG Reserved[2];    

} BUSENUM_UNPLUG_HARDWARE, *PBUSENUM_UNPLUG_HARDWARE;

typedef struct _BUSENUM_EJECT_HARDWARE
{
    //
    // sizeof (struct _EJECT_HARDWARE)
    //

    IN ULONG Size;                                    

    //
    // Serial number of the device to be ejected
    //

    ULONG   SerialNo;
    
    ULONG Reserved[2];    

} BUSENUM_EJECT_HARDWARE, *PBUSENUM_EJECT_HARDWARE;

#define SNGBUS_DRIVER_NAME		"SngBus"
#define SDLADRV_DRIVER_NAME		"SDLADRV"
#define SPROTOCOL_DRIVER_NAME	"SPROTOCOL"
#define WANPIPE_DRIVER_NAME		"WANPIPE"

#endif//#ifndef __WANPIPE_PUBLIC_H

